# pychacha

This is an implementation of ChaCha20 encryption in Python, with optional RSA encryption of the ChaCha20 key.

This code is provided as-is, with no warranty of safety, security, or functionality. Use at your own risk.
